@@ -18,7 +18,7 @@ main (int argc, char **argv)
     gchar*          gtime = NULL;
     GDate           gdate;
     struct tm       tm;
-    gboolean        bsun, bmoon;
+    gboolean        bmoon;
     time_t          phases[4];
     const GOptionEntry entries[] = {
 	{ "latitude", 0, 0, G_OPTION_ARG_DOUBLE, &latitude,
@@ -64,21 +64,17 @@ main (int argc, char **argv)
 	info.update = time(NULL);
     }
 
-    bsun = calc_sun_time(&info, info.update);
+    calc_sun_time(&info, info.update);
     bmoon = calc_moon(&info);
 
     printf ("  Latitude %7.3f %c  Longitude %7.3f %c for %s  All times UTC\n",
 	    fabs(latitude), (latitude >= 0. ? 'N' : 'S'),
 	    fabs(longitude), (longitude >= 0. ? 'E' : 'W'),
 	    asctime(gmtime(&info.update)));
-
-    if (bsun) {
-        printf("sunrise:   %s",
-	       (info.sunriseValid ? ctime(&info.sunrise) : "(invalid)\n"));
-        printf("sunset:    %s",
-	       (info.sunsetValid ? ctime(&info.sunset)  : "(invalid)\n"));
-    }
-
+    printf("sunrise:   %s",
+	   (info.sunriseValid ? ctime(&info.sunrise) : "(invalid)\n"));
+    printf("sunset:    %s",
+	   (info.sunsetValid ? ctime(&info.sunset)  : "(invalid)\n"));
     if (bmoon) {
 	printf("moonphase: %g\n", info.moonphase);
 	printf("moonlat:   %g\n", info.moonlatitude);
